==> cpl_5.3.1.orig.tar.gz: cpl-5.3.1/cplcore/cpl_fits.h <==
/* $Id: cpl_fits.h,v 1.6 2010/11/11 09:23:18 llundin Exp $
 *
 * This file is part of the ESO Common Pipeline Library
 * Copyright (C) 2001-2008 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*
 * $Author: llundin $
 * $Date: 2010/11/11 09:23:18 $
 * $Revision: 1.6 $
 * $Name: cpl-5_3_0-BRANCH $
 */

#ifndef CPL_FITS_H
#define CPL_FITS_H

/*-----------------------------------------------------------------------------
                                   Includes
 -----------------------------------------------------------------------------*/

#include <cpl_macros.h>

CPL_BEGIN_DECLS

int cpl_fits_count_extensions(const char *);

int cpl_fits_get_nb_extensions(const char *) CPL_ATTR_DEPRECATED;

int cpl_fits_find_extension(const char *, const char *);

int cpl_fits_get_extension_nb(const char *, const char *) CPL_ATTR_DEPRECATED;

CPL_END_DECLS

#endif

==> cpl_6.0.orig.tar.gz: cpl-6.0/cplcore/cpl_fits.h <==
/* $Id: cpl_fits.h,v 1.7 2011/07/21 08:11:22 llundin Exp $
 *
 * This file is part of the ESO Common Pipeline Library
 * Copyright (C) 2001-2008 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*
 * $Author: llundin $
 * $Date: 2011/07/21 08:11:22 $
 * $Revision: 1.7 $
 * $Name: cpl-6_0 $
 */

#ifndef CPL_FITS_H
#define CPL_FITS_H

/*-----------------------------------------------------------------------------
                                   Includes
 -----------------------------------------------------------------------------*/

#include <cpl_macros.h>
#include <cpl_type.h>

CPL_BEGIN_DECLS

cpl_size cpl_fits_count_extensions(const char *);

int cpl_fits_get_nb_extensions(const char *) CPL_ATTR_DEPRECATED;

cpl_size cpl_fits_find_extension(const char *, const char *);

int cpl_fits_get_extension_nb(const char *, const char *) CPL_ATTR_DEPRECATED;

CPL_END_DECLS

#endif
